[gnome-software] trivial: Show the details box for non-local packages without appdata
- From: Richard Hughes <rhughes src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [gnome-software] trivial: Show the details box for non-local packages without appdata
- Date: Thu, 30 Jan 2014 10:39:58 +0000 (UTC)
commit 34d2b427c2aff73844c9f273a2fad8ad68d8fcd5
Author: Richard Hughes <richard hughsie com>
Date: Thu Jan 30 10:39:39 2014 +0000
trivial: Show the details box for non-local packages without appdata
src/gs-shell-details.c | 12 ++++++++++--
1 files changed, 10 insertions(+), 2 deletions(-)
---
diff --git a/src/gs-shell-details.c b/src/gs-shell-details.c
index c8a9633..7485ca4 100644
--- a/src/gs-shell-details.c
+++ b/src/gs-shell-details.c
@@ -523,9 +523,17 @@ gs_shell_details_refresh_all (GsShellDetails *shell_details)
tmp = gs_app_get_description (priv->app);
gs_shell_details_set_description (shell_details, tmp);
/* do not show the 'Details' header if we have no description */
widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "application_details_details_title"));
- gtk_widget_set_visible (widget, tmp != NULL);
+ switch (gs_app_get_state (priv->app)) {
+ case GS_APP_STATE_LOCAL:
+ gtk_widget_set_visible (widget, tmp != NULL);
+ break;
+ default:
+ gtk_widget_set_visible (widget, TRUE);
+ break;
+ }
/* set the icon */
tmp = gs_app_get_metadata_item (priv->app, "DataDir::desktop-icon");
[
@@ -523,9 +523,17 @@ gs_shell_details_refresh_all (GsShellDetails *shell_details)
tmp = gs_app_get_description (priv->app);
gs_shell_details_set_description (shell_details, tmp);
- /* do not show the 'Details' header if we have no description */
+ /* do not show the 'Details' header if we are a local file and have no
+ * long description */
widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "application_details_details_title"));
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]